changeset 49625:2c79beda1333

(dired-move-to-filename-regexp): Support "K" suffix on "ls -alh" output.
author Juanma Barranquero <lekktu@gmail.com>
date Thu, 06 Feb 2003 08:19:26 +0000
parents ee553544342b
children 297de3d3bbae
files lisp/dired.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/dired.el	Thu Feb 06 08:19:03 2003 +0000
+++ b/lisp/dired.el	Thu Feb 06 08:19:26 2003 +0000
@@ -1572,11 +1572,11 @@
 	 ;; The "[0-9]" below requires the previous column to end in a digit.
 	 ;; This avoids recognizing `1 may 1997' as a date in the line:
 	 ;; -r--r--r--   1 may      1997        1168 Oct 19 16:49 README
 	 ;; The "[kMGTPEZY]?" below supports "ls -alh" output.
 	 ;; The ".*" below finds the last match if there are multiple matches.
 	 ;; This avoids recognizing `jservice  10  1024' as a date in the line:
 	 ;; drwxr-xr-x  3 jservice  10  1024 Jul  2  1997 esg-host
-    (concat ".*[0-9][kMGTPEZY]?" s
+    (concat ".*[0-9][kKMGTPEZY]?" s
 	    "\\(" western "\\|" western-comma "\\|" japanese "\\|" iso "\\)"
 	    s "+"))
   "Regular expression to match up to the file name in a directory listing.
@@ -1572,11 +1572,11 @@
 	 ;; This avoids recognizing `1 may 1997' as a date in the line:
 	 ;; -r--r--r--   1 may      1997        1168 Oct 19 16:49 README
-	 ;; The "[kMGTPEZY]?" below supports "ls -alh" output.
+	 ;; The "[kKMGTPEZY]?" below supports "ls -alh" output.
 	 ;; The ".*" below finds the last match if there are multiple matches.
 	 ;; This avoids recognizing `jservice  10  1024' as a date in the line: